==> haskell-typed-process-0.2.11.1-15-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 typed-process
version:              0.2.11.1
visibility:           public
id:                   typed-process-0.2.11.1-EXOKsjqYoIX76U2uXiWyhz
key:                  typed-process-0.2.11.1-EXOKsjqYoIX76U2uXiWyhz
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/typed-process
synopsis:             Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://github.com/fpco/typed-process#readme>

category:             System
abi:                  a51f921aec7478272ddfc60431a54d15
exposed:              True
exposed-modules:      System.Process.Typed System.Process.Typed.Internal
hidden-modules:       Paths_typed_process
import-dirs:          /usr/lib/ghc-9.2.8/site-local/typed-process-0.2.11.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/typed-process-0.2.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typed-process
hs-libraries:         HStyped-process-0.2.11.1-EXOKsjqYoIX76U2uXiWyhz
depends:
    async-2.2.5-EP8h1wWlEwVFRsNBoUfgIV base-4.16.4.0
    bytestring-0.11.4.0 process-1.6.16.0 stm-2.5.0.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:
    /usr/share/doc/haskell-typed-process/html/typed-process.haddock

haddock-html:         /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typed-process-0.2.11.1-17-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 typed-process
version:              0.2.11.1
visibility:           public
id:                   typed-process-0.2.11.1-LKXmiZ9T1rNLVZqHzuTEFw
key:                  typed-process-0.2.11.1-LKXmiZ9T1rNLVZqHzuTEFw
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/typed-process
synopsis:             Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://github.com/fpco/typed-process#readme>

category:             System
abi:                  d4f76f147d08e6520af19a390440b975
exposed:              True
exposed-modules:      System.Process.Typed System.Process.Typed.Internal
hidden-modules:       Paths_typed_process
import-dirs:          /usr/lib/ghc-9.2.8/site-local/typed-process-0.2.11.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/typed-process-0.2.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typed-process
hs-libraries:         HStyped-process-0.2.11.1-LKXmiZ9T1rNLVZqHzuTEFw
depends:
    async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85 base-4.16.4.0
    bytestring-0.11.4.0 process-1.6.16.0 stm-2.5.0.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:
    /usr/share/doc/haskell-typed-process/html/typed-process.haddock

haddock-html:         /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
